@@ -1,4 +1,4 @@
-#  Copyright (c) 2009-2013 David Caldwell,  All Rights Reserved.
+#  Copyright (c) 2009-2014 David Caldwell,  All Rights Reserved.
 
 package Net::DNS::Create::Bind;
 use Net::DNS::Create qw(internal full_host local_host email interval);
@@ -16,9 +16,16 @@ sub import {
     $config{$_} = $c{$_} for keys %c;
 }
 
+sub quote_txt(@) {
+    local $_ = $_[0];
+    s/[^[:print:]]/sprintf("\\%03o",ord($&))/ge;
+    s/["]/\\"/g;
+    "\"$_\""
+}
+
 sub txt(@) {
-    return "\"$_[0]\"" if scalar @_ == 1;
-    '('.join("\n" . " " x 41, map { "\"$_\"" } @_).')';
+    return quote_txt(@_) if scalar @_ == 1;
+    '('.join("\n" . " " x 41, map { quote_txt($_) } @_).')';
 }
 
 our @zone;
@@ -160,7 +167,7 @@ David Caldwell E<lt>david@porkrind.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2013 by David Caldwell
+Copyright (C) 2009-2014 by David Caldwell
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.12.4 or,
